[ARVADOS] updated: 0172bc3c12d893f7fd81a02a109c077b3ec1e2e6

git at public.curoverse.com git at public.curoverse.com
Thu May 15 09:30:20 EDT 2014


Summary of changes:
 services/api/app/controllers/arvados/v1/keep_disks_controller.rb | 4 ++--
 services/api/test/integration/keep_proxy_test.rb                 | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

       via  0172bc3c12d893f7fd81a02a109c077b3ec1e2e6 (commit)
      from  361a54cfb45565e9d85271eda4eff131231c33e4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 0172bc3c12d893f7fd81a02a109c077b3ec1e2e6
Author: Peter Amstutz <peter.amstutz at curoverse.com>
Date:   Thu May 15 09:30:13 2014 -0400

    2776: Changed "X-Need-Keep-Proxy" to "X-Keep-Proxy-Required" so Keep-related HTTP
    headers would start with "X-Keep-" for consistency.

diff --git a/services/api/test/integration/keep_proxy_test.rb b/services/api/test/integration/keep_proxy_test.rb
index c321462..76c7698 100644
--- a/services/api/test/integration/keep_proxy_test.rb
+++ b/services/api/test/integration/keep_proxy_test.rb
@@ -8,7 +8,7 @@ class KeepProxyTest < ActionDispatch::IntegrationTest
 
     assert_equal 3, disks.length
 
-    get "/arvados/v1/keep_disks", {:format => :json}, auth(:active).merge({'HTTP_X_NEED_KEEP_PROXY' => true})
+    get "/arvados/v1/keep_disks", {:format => :json}, auth(:active).merge({'HTTP_X_KEEP_PROXY_REQUIRED' => true})
     assert_response :success
     disks = json_response['items']
 

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/services/api/app/controllers/arvados/v1/keep_disks_controller.rb b/services/api/app/controllers/arvados/v1/keep_disks_controller.rb
index fb5524c..811e49e 100644
--- a/services/api/app/controllers/arvados/v1/keep_disks_controller.rb
+++ b/services/api/app/controllers/arvados/v1/keep_disks_controller.rb
@@ -27,9 +27,9 @@ class Arvados::V1::KeepDisksController < ApplicationController
   end
 
   def find_objects_for_index
     # X-Need-Keep-Proxy indicates the client is outside the cluster subnet and
     # needs to communicate with Keep via the proxy.
-    if request.headers['X-Need-Keep-Proxy'] and Rails.application.config.keep_proxy
+    if request.headers['X-Keep-Proxy-Required'] and Rails.application.config.keep_proxy
       # Build a KeepDisk model from the rails keep_proxy configuration
       require 'uri'
       u = URI.parse(Rails.application.config.keep_proxy)
@@ -27,9 +27,9 @@ class Arvados::V1::KeepDisksController < ApplicationController
 
   def find_objects_for_index
-    # X-Need-Keep-Proxy indicates the client is outside the cluster subnet and
+    # X-Keep-Proxy-Required indicates the client is outside the cluster subnet and
     # needs to communicate with Keep via the proxy.
-- 




More information about the arvados-commits mailing list